@@ -45,6 +45,7 @@
 #define KB_TEXT_HEIGHT   32
 
 #define KEY_DIR              "/apps/gnobots2"
+#define KEY_SHOW_TOOLBAR     "/apps/gnobots2/preferences/show_toolbar"
 #define KEY_CONTROL_KEY      "/apps/gnobots2/preferences/key%02d"
 #define KEY_THEME            "/apps/gnobots2/preferences/theme"
 #define KEY_CONFIGURATION    "/apps/gnobots2/preferences/configuration"
@@ -67,6 +68,7 @@ struct _GnobotsProperties {
   gboolean super_safe_moves;
   gboolean sound;
   gboolean splats;
+  gboolean show_toolbar;
   GdkColor bgcolour;
   gint     selected_graphics;
   gint     selected_config;
@@ -79,29 +81,10 @@ struct _GnobotsProperties {
 /* File Static Variables                                              */
 /**********************************************************************/
 static GtkWidget         *propbox      = NULL;
-static GtkWidget         *list_view    = NULL;
-enum {
-  PROPERTY_STRING,
-  VALUE_STRING,
-  INDEX_INT,
-  NCOLS
-}; /* Column indices for list */
 
 static GnobotsProperties  properties;
 
-static gint default_keys1[12] = {
-  GDK_Y, GDK_K, GDK_U, 
-  GDK_H, GDK_period, GDK_L,
-  GDK_B, GDK_J, GDK_N,
-  GDK_T, GDK_R, GDK_Return};
-
-static gint default_keys2[12] = {
-  GDK_Q, GDK_W, GDK_E, 
-  GDK_A, GDK_S, GDK_D,
-  GDK_Z, GDK_X, GDK_C,
-  GDK_T, GDK_R, GDK_Return};
-
-static gint default_keys3[12] = {
+static gint default_keys[12] = {
   GDK_KP_7, GDK_KP_8, GDK_KP_9, 
   GDK_KP_4, GDK_KP_5, GDK_KP_6,
   GDK_KP_1, GDK_KP_2, GDK_KP_3,
@@ -119,7 +102,6 @@ static GConfClient *gconf_client;
 static void apply_changes (void);
 static void apply_cb (GtkWidget*, gpointer);
 static gboolean delete_cb (GtkWidget*, gpointer);
-static void fill_property_list (void);
 static void pmap_selection (GtkWidget*, gpointer);
 static void type_selection (GtkWidget*, gpointer);
 static void safe_cb (GtkWidget*, gpointer);
@@ -166,7 +148,6 @@ apply_cb (GtkWidget *w, gpointer data)
   apply_changes ();
 
   gtk_widget_destroy (propbox);
-  list_view = NULL;
   propbox = NULL;
 }
 
@@ -182,295 +163,11 @@ apply_cb (GtkWidget *w, gpointer data)
 static gboolean
 delete_cb (GtkWidget *w, gpointer data)
 {
-  list_view = NULL;
   propbox = NULL;
 
   return FALSE;
 }
 
-
-/**
- * fill_property_list
- *
- * Description:
- * Fills the property list of configuration values
- **/
-static void
-fill_property_list (void)
-{
-  gchar *entry[2];
-  gchar buffer[256];
-  GameConfig *gc;
-  gboolean type2exist = TRUE;
-  GtkListStore *list;
-  GtkTreeIter iter;
-  int index = 0;
-
-  if (list_view == NULL) return;
-
-  list = (GtkListStore *) gtk_tree_view_get_model (GTK_TREE_VIEW (list_view));
-
-  gc = game_config_settings (properties.selected_config);
-
-  if ((gc->initial_type2 <= 0) && 
-      (gc->increment_type2 <= 0) && 
-      (gc->maximum_type2 <= 0)){
-    type2exist = FALSE;
-  }
-
-  gtk_list_store_clear (list);
-  /* I think this is just gtk_list_store_clear () */
-  
-  if (type2exist){
-    entry[0] = _("Initial Number of Type 1 Robots");
-  } else {
-    entry[0] = _("Initial Number of Robots");
-  }
-  sprintf (buffer, "%d", gc->initial_type1);
-  entry[1] = buffer;
-
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  if (type2exist){
-    entry[0] = _("Initial Number of Type 2 Robots");
-    sprintf (buffer, "%d", gc->initial_type2);
-    entry[1] = buffer;
-    gtk_list_store_append (list, &iter);
-    gtk_list_store_set (list, &iter,
-                        PROPERTY_STRING, entry[0],
-                        VALUE_STRING, entry[1],
-                        INDEX_INT, index,
-                        -1);
-    index++;
-  }
-
-  if (type2exist){
-    entry[0] = _("Increasing Number of Type 1 Robots per Level");
-  } else {
-    entry[0] = _("Increasing Number of Robots per Level");
-  }
-  sprintf (buffer, "%d", gc->increment_type1);
-  entry[1] = buffer;
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  if (type2exist){
-    entry[0] = _("Increasing Number of Type 2 Robots per Level");
-    sprintf (buffer, "%d", gc->increment_type2);
-    entry[1] = buffer;
-    gtk_list_store_append (list, &iter);
-    gtk_list_store_set (list, &iter,
-                        PROPERTY_STRING, entry[0],
-                        VALUE_STRING, entry[1],
-                        INDEX_INT, index,
-                        -1);
-    index++;
-  }
-
-  if (type2exist){
-    entry[0] = _("Maximum Number of Type 1 Robots");
-  } else {
-    entry[0] = _("Maximum Number of Robots");
-  }
-  if (gc->maximum_type1 > MAX_ROBOTS){
-    sprintf (buffer, _("Fill Screen"));
-  } else {
-    sprintf (buffer, "%d", gc->maximum_type1);
-  }
-  entry[1] = buffer;
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  if (type2exist){
-    entry[0] = _("Maximum Number of Type 2 Robots");
-    if (gc->maximum_type2 > MAX_ROBOTS){
-      sprintf (buffer, _("Fill Screen"));
-    } else {
-      sprintf (buffer, "%d", gc->maximum_type2);
-    }
-    entry[1] = buffer;
-    gtk_list_store_append (list, &iter);
-    gtk_list_store_set (list, &iter,
-                        PROPERTY_STRING, entry[0],
-                        VALUE_STRING, entry[1],
-                        INDEX_INT, index,
-                        -1);
-    index++;
-  }
-
-  if (type2exist){
-    entry[0] = _("Type 1 Robot Score");
-  } else {
-    entry[0] = _("Robot Score");
-  }
-  sprintf (buffer, "%d", gc->score_type1);
-  entry[1] = buffer;
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  if (type2exist){
-    entry[0] = _("Type 2 Robot Score");
-    sprintf (buffer, "%d", gc->score_type2);
-    entry[1] = buffer;
-    gtk_list_store_append (list, &iter);
-    gtk_list_store_set (list, &iter,
-                        PROPERTY_STRING, entry[0],
-                        VALUE_STRING, entry[1],
-                        INDEX_INT, index,
-                        -1);
-    index++;
-  }
-
-  if (type2exist){
-    entry[0] = _("Type 1 Robot Score When Waiting");
-  } else {
-    entry[0] = _("Robot Score When Waiting");
-  }
-  sprintf (buffer, "%d", gc->score_type1_waiting);
-  entry[1] = buffer;
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  if (type2exist){
-    entry[0] = _("Type 2 Robot Score When Waiting");
-    sprintf (buffer, "%d", gc->score_type2_waiting);
-    entry[1] = buffer;
-    gtk_list_store_append (list, &iter);
-    gtk_list_store_set (list, &iter,
-                        PROPERTY_STRING, entry[0],
-                        VALUE_STRING, entry[1],
-                        INDEX_INT, index,
-                        -1);
-    index++;
-  }
-
-  if (type2exist){
-    entry[0] = _("Type 1 Robot Score When Splatted");
-  } else {
-    entry[0] = _("Robot Score When Splatted");
-  }
-  sprintf (buffer, "%d", gc->score_type1_splatted);
-  entry[1] = buffer;
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  if (type2exist){
-    entry[0] = _("Type 2 Robot Score When Splatted");
-    sprintf (buffer, "%d", gc->score_type2_splatted);
-    entry[1] = buffer;
-    gtk_list_store_append (list, &iter);
-    gtk_list_store_set (list, &iter,
-                        PROPERTY_STRING, entry[0],
-                        VALUE_STRING, entry[1],
-                        INDEX_INT, index,
-                        -1);
-    index++;
-  }
-
-  entry[0] = _("Initial Number of Safe Teleports");
-  sprintf (buffer, "%d", gc->initial_safe_teleports);
-  entry[1] = buffer;
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  entry[0] = _("Number of Free Safe Teleports per Level");
-  sprintf (buffer, "%d", gc->free_safe_teleports);
-  entry[1] = buffer;
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  entry[0] = _("Kills Required While Waiting to Get A Safe Teleport");
-  sprintf (buffer, "%d", gc->num_robots_per_safe);
-  entry[1] = buffer;
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  entry[0] = _("Score Required To Get A Safe Teleport");
-  sprintf (buffer, "%d", gc->safe_score_boundary);
-  entry[1] = buffer;
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  entry[0] = _("Maximum Number of Safe Teleports");
-  sprintf (buffer, "%d", gc->max_safe_teleports);
-  entry[1] = buffer;
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-  index++;
-
-  entry[0] = _("Moveable Junkheaps");
-  if (gc->moveable_heaps) {
-    entry[1] = _("Yes");
-  } else {
-    entry[1] = _("No");
-  }
-  gtk_list_store_append (list, &iter);
-  gtk_list_store_set (list, &iter,
-                      PROPERTY_STRING, entry[0],
-                      VALUE_STRING, entry[1],
-                      INDEX_INT, index,
-                      -1);
-
-  /* gtk_tree_view_set_model (list_view, list); */
-
-}
-
-
 /**
  * pmap_selection
  * @widget: widget
@@ -507,11 +204,12 @@ type_selection (GtkWidget *widget, gpointer data)
   gint num = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 
   properties.selected_config = num;
-  fill_property_list ();
 
   gconf_set_configuration (game_config_name (properties.selected_config));
 
   set_game_config (properties.selected_config);
+
+  start_new_game ();
 }
 
 
@@ -701,187 +399,136 @@ show_properties_dialog (void)
   GtkWidget *chkbox;
   GtkWidget *table;
   GtkWidget *dbut;
-  GtkWidget *scrolled;
   GtkWidget *frame;
   GtkWidget *w;
   GtkWidget *controls_list;
   GtkTooltips *tooltips;
-  GtkListStore *list;
-  GtkTreeViewColumn *column;
-  GtkCellRenderer *renderer;
-  GtkTreeSelection *selection;
 
   if (propbox) 
     return;
 
   tooltips = gtk_tooltips_new ();
 
-  propbox = gtk_dialog_new_with_buttons (_("GNOME Robots Preferences"),
+  propbox = gtk_dialog_new_with_buttons (_("Robots Preferences"),
                                          GTK_WINDOW  (app),
                                          GTK_DIALOG_DESTROY_WITH_PARENT,
                                          GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
                                          NULL);
+  gtk_dialog_set_has_separator (GTK_DIALOG (propbox), FALSE);
+  gtk_container_set_border_width (GTK_CONTAINER (propbox), 5);
+  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (propbox)->vbox), 2);
   /* Set up notebook and add it to hbox of the gtk_dialog */
   g_signal_connect (G_OBJECT (propbox), "destroy",
                     G_CALLBACK (gtk_widget_destroyed), &propbox);
   
   notebook = gtk_notebook_new ();
+  gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (propbox)->vbox), notebook, 
                       TRUE, TRUE, 0);
 
   /* The configuration page */
-  cpage = gtk_vbox_new (FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (cpage), GNOME_PAD_SMALL);
+  cpage = gtk_vbox_new (FALSE, 18);
+  gtk_container_set_border_width (GTK_CONTAINER (cpage), 12);
 
   frame = games_frame_new (_("Game Type"));
-  gtk_box_pack_start (GTK_BOX (cpage), frame, TRUE, TRUE, GNOME_PAD);
+  gtk_box_pack_start (GTK_BOX (cpage), frame, TRUE, TRUE, 0);
 
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_vbox_new (FALSE, 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-  hbox = gtk_hbox_new (TRUE, GNOME_PAD);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, GNOME_PAD);
+  hbox = gtk_hbox_new (TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  if (game_state == STATE_NOT_PLAYING) {
-    typemenu = gtk_combo_box_new_text ();
-    g_signal_connect (G_OBJECT (typemenu), "changed",
-                      G_CALLBACK (type_selection), NULL);
-    fill_typemenu (typemenu);
-    gtk_box_pack_start_defaults (GTK_BOX (hbox), typemenu);
+  typemenu = gtk_combo_box_new_text ();
+  g_signal_connect (G_OBJECT (typemenu), "changed",
+		    G_CALLBACK (type_selection), NULL);
+  fill_typemenu (typemenu);
+  gtk_box_pack_start_defaults (GTK_BOX (hbox), typemenu);
+  
+  frame = games_frame_new (_("Options"));
+  gtk_box_pack_start (GTK_BOX (cpage), frame, FALSE, FALSE, 0);
+  vbox = gtk_vbox_new (TRUE, 6);
+  gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-    list = gtk_list_store_new (NCOLS,
-                               G_TYPE_STRING, /* Property */ 
-                               G_TYPE_STRING, /* Value */
-                               G_TYPE_INT); /* Index - remains hidden */
-    /* Create view */
-    list_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
-    g_object_unref (list); /* Do I need to create a list store? */
+  table = gtk_table_new (2, 2, FALSE);
+  gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+  gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
-    renderer = gtk_cell_renderer_text_new ();
-    column = gtk_tree_view_column_new_with_attributes (_("Property"), 
-                                                       renderer, 
-                                                       "text", PROPERTY_STRING, 
-                                                       NULL);
-    gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
-    
-    renderer = gtk_cell_renderer_text_new ();
-    column = gtk_tree_view_column_new_with_attributes (_("Value"), 
-                                                       renderer, 
-                                                       "text", VALUE_STRING, 
-                                                       NULL);
-    gtk_tree_view_append_column (GTK_TREE_VIEW (list_view), column);
+  chkbox = gtk_check_button_new_with_mnemonic (_("_Use safe moves"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), 
+				properties.safe_moves);
+  g_signal_connect (G_OBJECT (chkbox), "clicked",
+		    (GtkSignalFunc)safe_cb, NULL);
+  gtk_table_attach (GTK_TABLE (table), chkbox, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_tooltips_set_tip (tooltips, chkbox,
+			_("Prevent some dangerous moves"), 
+			_("Prevent accidental moves that result in getting killed."));
 
-    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list_view));
-    gtk_tree_selection_set_mode  (selection, GTK_SELECTION_SINGLE);
+  chkbox = gtk_check_button_new_with_mnemonic (_("U_se super safe moves"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.super_safe_moves);
+  g_signal_connect (G_OBJECT (chkbox), "clicked",
+		    (GtkSignalFunc)super_safe_cb, NULL);
+  gtk_table_attach (GTK_TABLE (table), chkbox, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
+  gtk_tooltips_set_tip (tooltips, chkbox,
+			_("Prevent all dangerous moves"), 
+			_("Prevents all moves that result in getting killed."));
 
-#if 0
-    gtk_clist_set_column_width (GTK_CLIST (clist), 0, 400);
-    gtk_clist_set_column_width (GTK_CLIST (clist), 1, 50);
-    gtk_clist_column_titles_passive (GTK_CLIST (clist));
-    gtk_clist_column_titles_show (GTK_CLIST (clist));
-#endif
+  chkbox = gtk_check_button_new_with_mnemonic (_("_Enable sounds"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.sound);
+  g_signal_connect (G_OBJECT (chkbox), "clicked",
+		    (GtkSignalFunc)sound_cb, NULL);
+  gtk_table_attach (GTK_TABLE (table), chkbox, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
+  gtk_tooltips_set_tip (tooltips, chkbox,
+			_("Play sounds for major events"), 
+			_("Play sounds for events like winning a level and dying."));
 
-    fill_property_list ();
+  chkbox = gtk_check_button_new_with_mnemonic (_("E_nable splats"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkbox), properties.splats);
+  g_signal_connect (G_OBJECT (chkbox), "clicked",
+		    (GtkSignalFunc)splat_cb, NULL);
+  gtk_table_attach (GTK_TABLE (table), chkbox, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
+  gtk_tooltips_set_tip (tooltips, chkbox,
+			_("Play a sound when two robots collide"), 
+			_("Play the most common, and potentially the most annoying, sound."));
 
-    /*gtk_widget_set_size_request (list_view, 300, 200);*/
-
-    scrolled = gtk_scrolled_window_new (NULL, NULL);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
-                                    GTK_POLICY_AUTOMATIC,
-                                    GTK_POLICY_AUTOMATIC);
-    gtk_scrolled_window_set_shadow_type 
-      (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_IN);
-    gtk_widget_set_size_request (scrolled, 400, 200);
-    gtk_container_add (GTK_CONTAINER (scrolled), list_view);
-
-    gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, GNOME_PAD_SMALL);
-
-    frame = games_frame_new (_("Options"));
-    gtk_box_pack_start (GTK_BOX (cpage), frame, TRUE, TRUE, GNOME_PAD);
-    vbox = gtk_vbox_new (TRUE, 6);
-    gtk_container_add (GTK_CONTAINER (frame), vbox);
-
-    table = gtk_table_new (2, 2, TRUE);
-    gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 6);
-    gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, TRUE, GNOME_PAD);
-
-    chkbox = gtk_check_button_new_with_label (_("Use safe moves"));
-    GTK_TOGGLE_BUTTON (chkbox)->active = properties.safe_moves;
-    g_signal_connect (G_OBJECT (chkbox), "clicked",
-                      (GtkSignalFunc)safe_cb, NULL);
-    gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 0, 1, 0, 1);
-    gtk_tooltips_set_tip (tooltips, chkbox,
-			  _("Prevent some dangerous moves"), 
-			  _("Prevent accidental moves that result in getting killed."));
-
-    chkbox = gtk_check_button_new_with_label (_("Use super safe moves"));
-    GTK_TOGGLE_BUTTON (chkbox)->active = properties.super_safe_moves;
-    g_signal_connect (G_OBJECT (chkbox), "clicked",
-                      (GtkSignalFunc)super_safe_cb, NULL);
-    gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 0, 1, 1, 2);
-    gtk_tooltips_set_tip (tooltips, chkbox,
-			  _("Prevent all dangerous moves"), 
-			  _("Prevents all moves that result in getting killed."));
-
-    chkbox = gtk_check_button_new_with_label (_("Enable sounds"));
-    GTK_TOGGLE_BUTTON (chkbox)->active = properties.sound;
-    g_signal_connect (G_OBJECT (chkbox), "clicked",
-                      (GtkSignalFunc)sound_cb, NULL);
-    gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 1, 2, 0, 1);
-    gtk_tooltips_set_tip (tooltips, chkbox,
-			  _("Play sounds for major events"), 
-			  _("Play sounds for events like winning a level and dying."));
-
-    chkbox = gtk_check_button_new_with_label (_("Enable splats"));
-    GTK_TOGGLE_BUTTON (chkbox)->active = properties.splats;
-    g_signal_connect (G_OBJECT (chkbox), "clicked",
-                      (GtkSignalFunc)splat_cb, NULL);
-    gtk_table_attach_defaults (GTK_TABLE (table), chkbox, 1, 2, 1, 2);
-    gtk_tooltips_set_tip (tooltips, chkbox,
-			  _("Play a sound when two robots collide"), 
-			  _("Play the most common, and potentially the most annoying, sound."));
-
-  } else {
-    label = gtk_label_new (_("You Cannot Change the Game Type When Playing"));
-    gtk_box_pack_start_defaults (GTK_BOX (hbox), label);
-
-  }
   label = gtk_label_new_with_mnemonic (_("Game"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), cpage, label);
 
 
   /* The graphics page */
-  gpage = gtk_vbox_new (FALSE, GNOME_PAD);
-  gtk_container_set_border_width (GTK_CONTAINER (gpage), GNOME_PAD_SMALL);
+  gpage = gtk_vbox_new (FALSE, 18);
+  gtk_container_set_border_width (GTK_CONTAINER (gpage), 12);
 
   frame = games_frame_new (_("Graphics Theme"));
-  gtk_box_pack_start (GTK_BOX (gpage), frame, FALSE, FALSE, GNOME_PAD);
+  gtk_box_pack_start (GTK_BOX (gpage), frame, FALSE, FALSE, 0);
 
   table = gtk_table_new (2, 2, FALSE);
-  gtk_container_set_border_width (GTK_CONTAINER (table), 0);
   gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 6);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 12);
   gtk_container_add (GTK_CONTAINER (frame), table);
 
-  label = gtk_label_new (_("Image theme:"));
+  label = gtk_label_new_with_mnemonic (_("_Image theme:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-  gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 0);
 
   pmapmenu = gtk_combo_box_new_text ();
   g_signal_connect (G_OBJECT (pmapmenu), "changed",
                     G_CALLBACK (pmap_selection), NULL);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), pmapmenu);
+
   fill_pmapmenu (pmapmenu);
   gtk_table_attach_defaults (GTK_TABLE (table), pmapmenu, 1, 2, 0, 1);
 
-  label = gtk_label_new (_("Background color:"));
+  label = gtk_label_new_with_mnemonic (_("_Background color:"));
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-  gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
 
   w  = gtk_color_button_new ();
   gtk_color_button_set_color (GTK_COLOR_BUTTON (w), &properties.bgcolour);
   g_signal_connect (G_OBJECT (w), "color_set",
                     G_CALLBACK (bg_color_callback), NULL);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), w);
 
   gtk_table_attach_defaults (GTK_TABLE (table), w, 1, 2, 1, 2);
 
@@ -889,11 +536,11 @@ show_properties_dialog (void)
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), gpage, label);
 
   /* The keyboard page */
-  kpage = gtk_vbox_new (FALSE, GNOME_PAD);
-  gtk_container_set_border_width (GTK_CONTAINER (kpage), GNOME_PAD_SMALL);
+  kpage = gtk_vbox_new (FALSE, 18);
+  gtk_container_set_border_width (GTK_CONTAINER (kpage), 12);
 
   frame = games_frame_new (_("Keyboard Controls"));
-  gtk_box_pack_start (GTK_BOX (kpage), frame, TRUE, TRUE, GNOME_PAD);
+  gtk_box_pack_start (GTK_BOX (kpage), frame, TRUE, TRUE, 0);
   vbox = gtk_vbox_new (FALSE, 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
@@ -913,25 +560,16 @@ show_properties_dialog (void)
 				    "/apps/gnobots2/preferences/key11",
 				    NULL);
 
-  gtk_box_pack_start (GTK_BOX (vbox), controls_list, TRUE, TRUE, GNOME_PAD);
+  gtk_box_pack_start (GTK_BOX (vbox), controls_list, TRUE, TRUE, 0);
 
-  hbox = gtk_hbox_new (TRUE, GNOME_PAD);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, GNOME_PAD);
+  hbox = gtk_hbutton_box_new ();
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_START);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  dbut = gtk_button_new_with_label (_("Use the Keypad"));
+  dbut = gtk_button_new_with_mnemonic (_("_Restore Defaults"));
   g_signal_connect (G_OBJECT (dbut), "clicked",
-                    G_CALLBACK (defkey_cb), (gpointer)default_keys3);  
-  gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, TRUE, GNOME_PAD);
-
-  dbut = gtk_button_new_with_label (_("Use Left Hand Keys"));
-  g_signal_connect (G_OBJECT (dbut), "clicked",
-                    G_CALLBACK (defkey_cb), (gpointer)default_keys2);  
-  gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, TRUE, GNOME_PAD);
-
-  dbut = gtk_button_new_with_label (_("Use Original Robots Keys"));
-  g_signal_connect (G_OBJECT (dbut), "clicked",
-                    G_CALLBACK (defkey_cb), (gpointer)default_keys1);  
-  gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, TRUE, GNOME_PAD);
+                    G_CALLBACK (defkey_cb), (gpointer)default_keys);  
+  gtk_box_pack_start (GTK_BOX (hbox), dbut, FALSE, FALSE, 0);
 
   label = gtk_label_new_with_mnemonic (_("Keyboard"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), kpage, label);
@@ -983,7 +621,7 @@ load_properties (void)
   gchar * bgcolour;
 
   for (i = 0; i < 12; i++) {
-    properties.keys[i] = default_keys1[i];
+    properties.keys[i] = default_keys[i];
 
     sprintf (buffer, KEY_CONTROL_KEY, i);
 
@@ -992,7 +630,7 @@ load_properties (void)
       properties.keys[i] = gdk_keyval_from_name (str);
     }
     if ((str == NULL) || (properties.keys[i] == GDK_VoidSymbol)) {
-      properties.keys[i] = default_keys3[i];
+      properties.keys[i] = default_keys[i];
     }
     g_free (str);
   }
@@ -1039,6 +677,8 @@ load_properties (void)
                                             KEY_ENABLE_SOUND, NULL);
   properties.splats = gconf_client_get_bool (get_gconf_client (),
                                              KEY_ENABLE_SPLATS, NULL);
+  properties.show_toolbar = gconf_client_get_bool (get_gconf_client (),
+						   KEY_SHOW_TOOLBAR, NULL);
 
   set_game_graphics (properties.selected_graphics);
   set_game_config (properties.selected_config);
@@ -1102,6 +742,13 @@ gconf_set_enable_splats (gboolean value)
                          value, NULL);
 }
 
+void
+gconf_set_show_toolbar (gboolean value)
+{
+  gconf_client_set_bool (get_gconf_client (), KEY_SHOW_TOOLBAR,
+			 value, NULL);
+}
+
 void
 gconf_set_control_key (gint i, gchar *value)
 {
@@ -1204,6 +851,23 @@ properties_splats (void)
   return properties.splats;
 }
 
+
+/**
+ * properties_show_toolbar
+ *
+ * Description:
+ * returns toolbar setting
+ *
+ * Returns:
+ * TRUE if splats are selected
+ **/
+gboolean
+properties_show_toolbar (void)
+{
+  return properties.show_toolbar;
+}
+
+
 /**
  * properties_set_config
  * @n: config number
